
clear all
close all

% What follows is an example to demonstrate the ConstrainedGust
% script with different gust amplituds and an demonstration of
% writebladed / readbladed.

%% Example: Spherical gust in Mann (IEC) turbulence
% Domain
[x,y,z] = ndgrid(...
    linspace(0,300,2^6), ...
    linspace(0,300,2^6), ...
    linspace(0,300,2^6));

% Gust parameters
A = 4;              % Gust amplitude [m/s]
l = 50;             % Gust volume [m]
shape = 'Ellipsoid';% Gust shape ('Box'/'Ellipsoid'). 
x0 = [x(20,1,1);... % Gust position [m]
      y(1,20,1);...
      z(1,1,20)];

% Spectrum
spectrum = 'MannIEC';
sigma1 = 1;         % Longitudinal standard deviation [m/s].
h = 90;             % Hub height [m].

% Turbulence seed (set to specific value in order to have the same
% background turbulence)
seed = 1;

% Velocity field
[u,v,w] = ConstrainedGust(x,y,z,A,x0,l,shape,seed,spectrum,sigma1,h);

U = 10;             % Mean wind speed [m/s].

% Save wind field in wnd file
writebladed('Amplitude_4',u,v,w,x,y,z,U);

% A smaller gust amplitude
A = 2;              % Gust amplitude [m/s]
% Velocity field
[u,v,w] = ConstrainedGust(x,y,z,A,x0,l,shape,seed,spectrum,sigma1,h);
% Save wind field in another wnd file
writebladed('Amplitude_2',u,v,w,x,y,z,U);

% A gust amplitude equal to zero
A = 0;              % Gust amplitude [m/s]
% Velocity field
[u,v,w] = ConstrainedGust(x,y,z,A,x0,l,shape,seed,spectrum,sigma1,h);
% Save wind field in another wnd file
writebladed('Amplitude_0',u,v,w,x,y,z,U);

clear all
% read all wind files
[u4,v4,w4,x,y,z,U,t]=readbladed('Amplitude_4');
[u2,v2,w2,x,y,z,U,t]=readbladed('Amplitude_2');
[u0,v0,w0,x,y,z,U,t]=readbladed('Amplitude_0');
% Time series of longitudinal wind speed at gust center (i.e. the same
% indices are used as for x0)
plot(t,u4(:,20,20),t,u2(:,20,20),t,u0(:,20,20))
xlabel('time (s)')
ylabel('u (m/s)')
legend('A=4','A=2','A=0')
